@@ -15,36 +15,36 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .literals import SortOrderTypeType
 from .paginator import ListSecretsPaginator
 from .type_defs import (
-    CancelRotateSecretResponseResponseTypeDef,
-    CreateSecretResponseResponseTypeDef,
-    DeleteResourcePolicyResponseResponseTypeDef,
-    DeleteSecretResponseResponseTypeDef,
-    DescribeSecretResponseResponseTypeDef,
+    CancelRotateSecretResponseTypeDef,
+    CreateSecretResponseTypeDef,
+    DeleteResourcePolicyResponseTypeDef,
+    DeleteSecretResponseTypeDef,
+    DescribeSecretResponseTypeDef,
     FilterTypeDef,
-    GetRandomPasswordResponseResponseTypeDef,
-    GetResourcePolicyResponseResponseTypeDef,
-    GetSecretValueResponseResponseTypeDef,
-    ListSecretsResponseResponseTypeDef,
-    ListSecretVersionIdsResponseResponseTypeDef,
-    PutResourcePolicyResponseResponseTypeDef,
-    PutSecretValueResponseResponseTypeDef,
-    RemoveRegionsFromReplicationResponseResponseTypeDef,
+    GetRandomPasswordResponseTypeDef,
+    GetResourcePolicyResponseTypeDef,
+    GetSecretValueResponseTypeDef,
+    ListSecretsResponseTypeDef,
+    ListSecretVersionIdsResponseTypeDef,
+    PutResourcePolicyResponseTypeDef,
+    PutSecretValueResponseTypeDef,
+    RemoveRegionsFromReplicationResponseTypeDef,
     ReplicaRegionTypeTypeDef,
-    ReplicateSecretToRegionsResponseResponseTypeDef,
-    RestoreSecretResponseResponseTypeDef,
-    RotateSecretResponseResponseTypeDef,
+    ReplicateSecretToRegionsResponseTypeDef,
+    RestoreSecretResponseTypeDef,
+    RotateSecretResponseTypeDef,
     RotationRulesTypeTypeDef,
-    StopReplicationToReplicaResponseResponseTypeDef,
+    StopReplicationToReplicaResponseTypeDef,
     TagTypeDef,
-    UpdateSecretResponseResponseTypeDef,
-    UpdateSecretVersionStageResponseResponseTypeDef,
-    ValidateResourcePolicyResponseResponseTypeDef,
+    UpdateSecretResponseTypeDef,
+    UpdateSecretVersionStageResponseTypeDef,
+    ValidateResourcePolicyResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -80,29 +80,34 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class SecretsManagerClient:
+class SecretsManagerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        SecretsManagerClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#can_paginate)
         """
 
-    def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseResponseTypeDef:
+    def cancel_rotate_secret(self, *, SecretId: str) -> CancelRotateSecretResponseTypeDef:
         """
         Disables automatic scheduled rotation and cancels the rotation of a secret if
         currently in progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.cancel_rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#cancel_rotate_secret)
         """
 
@@ -118,21 +123,19 @@ class SecretsManagerClient:
         Tags: List["TagTypeDef"] = None,
         AddReplicaRegions: List["ReplicaRegionTypeTypeDef"] = None,
         ForceOverwriteReplicaSecret: bool = None
-    ) -> CreateSecretResponseResponseTypeDef:
+    ) -> CreateSecretResponseTypeDef:
         """
         Creates a new secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.create_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#create_secret)
         """
 
-    def delete_resource_policy(
-        self, *, SecretId: str
-    ) -> DeleteResourcePolicyResponseResponseTypeDef:
+    def delete_resource_policy(self, *, SecretId: str) -> DeleteResourcePolicyResponseTypeDef:
         """
         Deletes the resource-based permission policy attached to the secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.delete_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_resource_policy)
         """
 
@@ -142,19 +145,19 @@ class SecretsManagerClient:
         SecretId: str,
         RecoveryWindowInDays: int = None,
         ForceDeleteWithoutRecovery: bool = None
-    ) -> DeleteSecretResponseResponseTypeDef:
+    ) -> DeleteSecretResponseTypeDef:
         """
         Deletes an entire secret and all of the versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.delete_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#delete_secret)
         """
 
-    def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseResponseTypeDef:
+    def describe_secret(self, *, SecretId: str) -> DescribeSecretResponseTypeDef:
         """
         Retrieves the details of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.describe_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#describe_secret)
         """
 
@@ -168,7 +171,7 @@ class SecretsManagerClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#generate_presigned_url)
         """
 
@@ -183,31 +186,31 @@ class SecretsManagerClient:
         ExcludeLowercase: bool = None,
         IncludeSpace: bool = None,
         RequireEachIncludedType: bool = None
-    ) -> GetRandomPasswordResponseResponseTypeDef:
+    ) -> GetRandomPasswordResponseTypeDef:
         """
         Generates a random password of the specified complexity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.get_random_password)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_random_password)
         """
 
-    def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseResponseTypeDef:
+    def get_resource_policy(self, *, SecretId: str) -> GetResourcePolicyResponseTypeDef:
         """
         Retrieves the JSON text of the resource-based policy document attached to the
         specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.get_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_resource_policy)
         """
 
     def get_secret_value(
         self, *, SecretId: str, VersionId: str = None, VersionStage: str = None
-    ) -> GetSecretValueResponseResponseTypeDef:
+    ) -> GetSecretValueResponseTypeDef:
         """
         Retrieves the contents of the encrypted fields `SecretString` or `SecretBinary`
         from the specified version of a secret, whichever contains content.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.get_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#get_secret_value)
         """
 
@@ -218,11 +221,11 @@ class SecretsManagerClient:
         MaxResults: int = None,
         NextToken: str = None,
         IncludeDeprecated: bool = None
-    ) -> ListSecretVersionIdsResponseResponseTypeDef:
+    ) -> ListSecretVersionIdsResponseTypeDef:
         """
         Lists all of the versions attached to the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.list_secret_version_ids)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secret_version_ids)
         """
 
@@ -233,22 +236,22 @@ class SecretsManagerClient:
         NextToken: str = None,
         Filters: List["FilterTypeDef"] = None,
         SortOrder: SortOrderTypeType = None
-    ) -> ListSecretsResponseResponseTypeDef:
+    ) -> ListSecretsResponseTypeDef:
         """
         Lists all of the secrets that are stored by Secrets Manager in the AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#list_secrets)
         """
 
     def put_resource_policy(
         self, *, SecretId: str, ResourcePolicy: str, BlockPublicPolicy: bool = None
-    ) -> PutResourcePolicyResponseResponseTypeDef:
+    ) -> PutResourcePolicyResponseTypeDef:
         """
         Attaches the contents of the specified resource-based permission policy to a
         secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.put_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_resource_policy)
         """
 
@@ -260,21 +263,21 @@ class SecretsManagerClient:
         SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None,
         VersionStages: List[str] = None
-    ) -> PutSecretValueResponseResponseTypeDef:
+    ) -> PutSecretValueResponseTypeDef:
         """
         Stores a new encrypted secret value in the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.put_secret_value)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#put_secret_value)
         """
 
     def remove_regions_from_replication(
         self, *, SecretId: str, RemoveReplicaRegions: List[str]
-    ) -> RemoveRegionsFromReplicationResponseResponseTypeDef:
+    ) -> RemoveRegionsFromReplicationResponseTypeDef:
         """
         Remove regions from replication.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.remove_regions_from_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#remove_regions_from_replication)
         """
 
@@ -284,21 +287,21 @@ class SecretsManagerClient:
         SecretId: str,
         AddReplicaRegions: List["ReplicaRegionTypeTypeDef"],
         ForceOverwriteReplicaSecret: bool = None
-    ) -> ReplicateSecretToRegionsResponseResponseTypeDef:
+    ) -> ReplicateSecretToRegionsResponseTypeDef:
         """
         Converts an existing secret to a multi-Region secret and begins replication the
         secret to a list of new regions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.replicate_secret_to_regions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#replicate_secret_to_regions)
         """
 
-    def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseResponseTypeDef:
+    def restore_secret(self, *, SecretId: str) -> RestoreSecretResponseTypeDef:
         """
         Cancels the scheduled deletion of a secret by removing the `DeletedDate` time
         stamp.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.restore_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#restore_secret)
         """
 
@@ -309,22 +312,22 @@ class SecretsManagerClient:
         ClientRequestToken: str = None,
         RotationLambdaARN: str = None,
         RotationRules: "RotationRulesTypeTypeDef" = None
-    ) -> RotateSecretResponseResponseTypeDef:
+    ) -> RotateSecretResponseTypeDef:
         """
         Configures and starts the asynchronous process of rotating this secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.rotate_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#rotate_secret)
         """
 
     def stop_replication_to_replica(
         self, *, SecretId: str
-    ) -> StopReplicationToReplicaResponseResponseTypeDef:
+    ) -> StopReplicationToReplicaResponseTypeDef:
         """
         Removes the secret from replication and promotes the secret to a regional secret
         in the replica Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.stop_replication_to_replica)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#stop_replication_to_replica)
         """
 
@@ -333,7 +336,7 @@ class SecretsManagerClient:
         Attaches one or more tags, each consisting of a key name and a value, to the
         specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#tag_resource)
         """
 
@@ -341,7 +344,7 @@ class SecretsManagerClient:
         """
         Removes one or more tags from the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#untag_resource)
         """
 
@@ -354,11 +357,11 @@ class SecretsManagerClient:
         KmsKeyId: str = None,
         SecretBinary: Union[bytes, IO[bytes], StreamingBody] = None,
         SecretString: str = None
-    ) -> UpdateSecretResponseResponseTypeDef:
+    ) -> UpdateSecretResponseTypeDef:
         """
         Modifies many of the details of the specified secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.update_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret)
         """
 
@@ -369,27 +372,27 @@ class SecretsManagerClient:
         VersionStage: str,
         RemoveFromVersionId: str = None,
         MoveToVersionId: str = None
-    ) -> UpdateSecretVersionStageResponseResponseTypeDef:
+    ) -> UpdateSecretVersionStageResponseTypeDef:
         """
         Modifies the staging labels attached to a version of a secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.update_secret_version_stage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#update_secret_version_stage)
         """
 
     def validate_resource_policy(
         self, *, ResourcePolicy: str, SecretId: str = None
-    ) -> ValidateResourcePolicyResponseResponseTypeDef:
+    ) -> ValidateResourcePolicyResponseTypeDef:
         """
         Validates that the resource policy does not grant a wide range of IAM principals
         access to your secret.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Client.validate_resource_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client.html#validate_resource_policy)
         """
 
     def get_paginator(self, operation_name: Literal["list_secrets"]) -> ListSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
