@@ -23,14 +23,14 @@ from typing import Iterator, List
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import SortOrderTypeType
-from .type_defs import FilterTypeDef, ListSecretsResponseResponseTypeDef, PaginatorConfigTypeDef
+from .type_defs import FilterTypeDef, ListSecretsResponseTypeDef, PaginatorConfigTypeDef
 
 __all__ = ("ListSecretsPaginator",)
 
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
     """
 
@@ -40,8 +40,8 @@ class ListSecretsPaginator(Boto3Paginator):
         Filters: List["FilterTypeDef"] = None,
         SortOrder: SortOrderTypeType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListSecretsResponseResponseTypeDef]:
+    ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.104/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
